@@ -25,16 +25,16 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
   ## algorithm, that is when type=NS
 
   x <- as.matrix(x)  ## makes sure x is a matrix
-  x <- x / as.vector( Rfast::rowsums(x) )  ## makes sure the data sum to 1
-  n <- nrow(x)
-  p <- ncol(x)
+  x <- x / Rfast::rowsums(x)  ## makes sure the data sum to 1
+  n <- dim(x)[1]
+  p <- dim(x)[2]
   ina <- as.numeric(ina)
   xnew <- as.matrix(xnew)
   xnew <- matrix( xnew, ncol = p ) ## makes sure xnew is a matrix
-  xnew <- xnew / as.vector( Rfast::rowsums(xnew) )  ## make the data sum to 1
+  xnew <- xnew / Rfast::rowsums(xnew)  ## make the data sum to 1
   nc <- max(ina)  ## The number of groups
   nu <- nrow(xnew)
-  disa <- matrix(0, nu, n)
+  disa <- matrix(0, n, nu)
 
   if (apostasi == "CS" & a == 0) {
     apostasi = "Ait"
@@ -42,41 +42,42 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
 
   if (apostasi == "ESOV") {
     xa <- x^a
-    zx <- xa / as.vector( Rfast::rowsums( xa ) ) ## The power transformation is applied
+    zx <- xa / Rfast::rowsums( xa )  ## The power transformation is applied
     za <- xnew^a
-    znew <- za / as.vector( Rfast::rowsums( za ) ) ## The power transformation is applied
+    znew <- za / Rfast::rowsums( za )  ## The power transformation is applied
 
     for (i in 1:nu) {
       zan <- znew[i, ]
       for (j in 1:n) {
-        ma <- zan + zx[j, ]
-        disa[i, j] <- sqrt( sum( zan * log( 2 * zan/ma ) +
-                      zx[j, ] * log( 2 * zx[j, ]/ma ), na.rm = TRUE ) )
+        zxj <- zx[j, ]
+        ma <- zan + zxj
+        disa[j, i] <- sqrt( sum( zan * log( 2 * zan / ma ) +
+                                   zxj * log( 2 * zxj/ma ), na.rm = TRUE ) )
       }
     }
 
   } else  if ( apostasi == "taxicab" ) {
     xa <- x^a
-    zx <- xa / as.vector( Rfast::rowsums( xa ) ) ## The power transformation is applied
+    zx <- xa / Rfast::rowsums( xa )  ## The power transformation is applied
     za <- xnew^a
-    znew <- za / as.vector( Rfast::rowsums( za ) ) ## The power transformation is applied
+    znew <- za / Rfast::rowsums( za )  ## The power transformation is applied
 
     for (i in 1:nu) {
       b <- t(zx) - znew[i, ]
-      disa[i, ] <- as.vector( Rfast::colsums( abs(b) ) )
+      disa[, i] <- Rfast::colsums( abs(b) )
     }
 
   } else if ( apostasi == "Ait" ) {
     ## this requires non zero data ## be careful
     xa <- log(x)
-    zx <- xa - as.vector( Rfast::rowmeans( xa ) )
+    zx <- xa - Rfast::rowmeans( xa )
     za <- log(xnew)
-    znew <- za - as.vector( Rfast::rowmeans( za ) )
+    znew <- za - Rfast::rowmeans( za )
     tzx <- t(zx)
 
     for (i in 1:nu) {
       zz <- tzx - znew[i, ]
-      disa[i, ] <-  sqrt( as.vector( Rfast::colsums( zz^2 ) ) )
+      disa[, i] <-  sqrt( Rfast::colsums( zz^2 ) )
     }
 
   } else if ( apostasi == "Hellinger" ) {
@@ -86,55 +87,57 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
 
     for (i in 1:nu) {
       zz <- tzx - znew[i, ]
-      disa[i, ] <-  sqrt( as.vector( Rfast::colsums( zz^2 ) ) )
+      disa[, i] <-  sqrt( Rfast::colsums( zz^2 ) )
     }
     disa <- disa / sqrt(2)
 
   } else if ( apostasi == "angular" ) {
     zx <- sqrt(x)
     znew <- sqrt(xnew)
-    disa <- tcrossprod( znew, zx )
+    disa <- tcrossprod(zx, znew )
     disa[disa >= 1] <- 1
     disa <- acos(disa)
 
   }  else if ( apostasi == "CS" ) {
-     xa <- x^a
-     zx <- xa / as.vector( Rfast::rowsums( xa ) ) ## The power transformation is applied
-     za <- xnew^a
-    znew <- za / as.vector( Rfast::rowsums( za ) ) ## The power transformation is applied
+    xa <- x^a
+    zx <- xa / Rfast::rowsums( xa )  ## The power transformation is applied
+    za <- xnew^a
+    znew <- za / Rfast::rowsums( za )  ## The power transformation is applied
 
-     for (i in 1:nu) {
-       for (j in 1:n) {
-         sa <- ( zx[j, ] - znew[i, ] )^2 / (zx[j, ] + znew[i, ])
-         disa[i, j] <- sum( sa[ abs(sa)<Inf ] )
-       }
-     }
-     disa <- 1 / abs(a) * sqrt(2 * p) * sqrt(disa)
+    for (i in 1:nu) {
+      znewi <- znew[i, ]
+      for (j in 1:n) {
+        zxj <- zx[j, ]
+        sa <- ( zxj - znewi )^2 / ( zxj + znewi )
+        disa[j, i] <- sum( sa[ abs(sa)<Inf ] )
+      }
+    }
+    disa <- sqrt(2 * p) * sqrt(disa) / abs(a)
   }
 
-  ta <- matrix(nrow = nu, ncol = nc)
-
   if (type == "NS") {
     ## Non Standard algorithm
 
-    for (m in 1:nc) {
-      disa <- t( apply(disa, 1, sort) )
-      if (mesos == TRUE) {
-        ta[, m] <- as.vector( Rfast::rowmeans( disa[, 1:k] ) )
+    ta <- matrix(nrow = nu, ncol = nc)
 
+    for (m in 1:nc) {
+      apo <- disa[ina == m, ]
+      apo <- Rfast::sort_mat(apo)
+      if (mesos == TRUE) {
+        ta[, m] <- Rfast::colmeans( apo[1:k, ] )
       } else {
-        ta[, m] <- k / as.vector( Rfast::rowsums( 1 / disa[, 1:k] ) )
+        ta[, m] <- k / Rfast::colsums( 1 / apo[1:k, ] )
       }
     }
 
-    g <- apply(ta, 1, which.min)
+    g <- max.col(-ta)
 
   } else {   ## if type is "S"
     ## Standard algorithm
 
     g <- numeric(nu)
     for (l in 1:nu) {
-      xa <- cbind(ina, disa[l, ])
+      xa <- cbind(ina, disa[, l])
       qan <- xa[order(xa[, 2]), ]
       sa <- qan[1:k, 1]
       tab <- table(sa)
