@@ -8,14 +8,14 @@ ddiri <- function(x, a, logged = TRUE) {
   ## x is the compositional data
   ## a is a vector with the parameters
 
-  if ( is.null(nrow(x)) ) {
+  if ( is.null(dim(x)[1]) ) {
     x <- x / sum(x)
     f <- lgamma( sum(a) ) - sum( lgamma(a) ) + sum( log(x) * (a - 1) )
 
   } else {
 
     x <- as.matrix(x)  ## makes sure x is a matrix
-    x <- x / as.vector( Rfast::rowsums(x) )  ## makes sure x is compositional data
+    x <- x / Rfast::rowsums(x)  ## makes sure x is compositional data
     f <- lgamma( sum(a) ) - sum( lgamma(a) ) + as.vector( log(x) %*% (a - 1) )
   }
 
