@@ -19,44 +19,44 @@ diri.contour <- function(a, n = 100, x = NULL) {
     for (j in 1:n) {
       if ( x2[j] < sqrt3 * x1[i] ) {
         ## This checks if the point will lie inside the triangle
-        ## the next three lines invert the points which lie inside 
+        ## the next three lines invert the points which lie inside
         ## the triangle back into the composition in S^2
-        w3 <- (2 * x2[j])/sqrt3
+        w3 <- 2 * x2[j] / sqrt3
         w2 <- x1[i] - x2[j]/sqrt3
         w1 <- 1 - w2 - w3
         w <- c(w1, w2, w3)
-        can <- (1 / beta) * prod( w^(a - 1) )
-        if (abs(can) < Inf)  mat[i, j] <- can  else  mat[i, j] <- NA 
-      } else  mat[i, j] <- NA 
+        can <- prod( w^(a - 1) ) / beta
+        if (abs(can) < Inf)  mat[i, j] <- can  else  mat[i, j] <- NA
+      } else  mat[i, j] <- NA
     }
   }
   for (i in c(n/2 + 1):n) {
     for (j in 1:n) {
       ## This checks if the point will lie inside the triangle
       if ( x2[j] < sqrt3 - sqrt3 * x1[i] ) {
-        ## the next three lines invert the points which lie inside 
+        ## the next three lines invert the points which lie inside
         ## the triangle back into the composition in S^2
-        w3 <- (2 * x2[j])/sqrt3
+        w3 <- 2 * x2[j] / sqrt3
         w2 <- x1[i] - x2[j]/sqrt3
         w1 <- 1 - w2 - w3
         w <- round(c(w1, w2, w3), 6)
-        can <- (1 / beta) * prod(w^(a - 1))
-        if (abs(can) < Inf)  mat[i, j] <- can  else  mat[i, j] <- NA 
-      } else  mat[i, j] <- NA 
+        can <- prod( w^(a - 1) ) / beta
+        if (abs(can) < Inf)  mat[i, j] <- can  else  mat[i, j] <- NA
+      } else  mat[i, j] <- NA
     }
   }
 
   contour(x1, x2, mat, col = 3)  ## contour plots
-  b1 <- c(1/2, 0, 1, 1/2)
+  b1 <- c(0.5, 0, 1, 0.5)
   b2 <- c(sqrt3/2, 0, 0, sqrt3/2)
   b <- cbind(b1, b2)
   ## the next line draws the triangle in the two dimensions
   points(b[, 1], b[, 2], type = "l", xlab = " ", ylab = " ")
-  
+
   if ( !is.null(x) ) {
     x <- as.matrix(x)
-    x <- x / as.vector( Rfast::rowsums(x) )
-    proj <- matrix(c(0, 1, 1/2, 0, 0, sqrt3/2), ncol = 2)
+    x <- x / Rfast::rowsums(x)
+    proj <- matrix(c(0, 1, 0.5, 0, 0, sqrt3/2), ncol = 2)
     xa <- x %*% proj
     points(xa[, 1], xa[, 2])
   }
