@@ -12,15 +12,15 @@ diri.est <- function(x, type = 'mle') {
   ## type = 'ent' means to use the entropy for the estimation
 
   x <- as.matrix(x)  ## makes sure x is a matrix
-  x <- x / as.vector( Rfast::rowsums(x) )  ## makes sure x is compositional data
-  n <- nrow(x)  ## sample size
+  x <- x / Rfast::rowsums(x)  ## makes sure x is compositional data
+  n <- dim(x)[1]  ## sample size
   z <- log(x)
 
   ## loglik is for the 'mle' type
   loglik <- function(param, z) {
      param <- exp(param)
-    -( n * lgamma( sum(param) ) - n * sum( lgamma(param) ) +
-     sum( z %*% (param - 1) ) )
+    - n * lgamma( sum(param) ) + n * sum( lgamma(param) ) -
+     sum( z %*% (param - 1) )
   }
 
   ## diri is for the 'prec' type
@@ -28,15 +28,15 @@ diri.est <- function(x, type = 'mle') {
    phi <- exp(param[1])
    b <- c(1, exp(param[-1]) )
    b <- b / sum(b)
-   f <-  -( n * lgamma(phi) - n * sum( lgamma(phi * b) ) +
-   sum( z %*% (phi * b - 1) ) )
+   f <-  - n * lgamma(phi) + n * sum( lgamma(phi * b) ) -
+   sum( z %*% (phi * b - 1) )
    f
   }
 
   if (type == 'mle') {
     runtime <- proc.time()
     options(warn = -1)
-    da <- nlm(loglik, colMeans(x) * 10, z = z, iterlim = 10000)
+    da <- nlm(loglik, Rfast::colmeans(x) * 10, z = z, iterlim = 10000)
     da <- nlm(loglik, da$estimate, z = z, iterlim = 10000)
     da <- nlm(loglik, da$estimate, z = z, iterlim = 10000)
     da <- optim(da$estimate, loglik, z = z, control = list(maxit = 2000),
@@ -50,14 +50,14 @@ diri.est <- function(x, type = 'mle') {
   if (type == 'prec') {
     runtime <- proc.time()
     options(warn = -1)
-    da <- nlm(diriphi, c(10, colMeans(x)[-1]), z = z, iterlim = 2000)
+    da <- nlm(diriphi, c(10, Rfast::colmeans(x)[-1]), z = z, iterlim = 2000)
     da <- nlm(diriphi, da$estimate, z = z, iterlim = 2000)
     da <- nlm(diriphi, da$estimate, z = z, iterlim = 2000, hessian = TRUE)
     da <- optim(da$estimate, diriphi, z = z, control = list(maxit = 3000),
     hessian = TRUE)
     phi <- exp(da$par[1])
     a <- c( 1, exp(da$par[-1]) )
-    a <- a/sum(a)
+    a <- a / sum(a)
 
     runtime <- proc.time() - runtime
     result <- list( loglik = -da$value, phi = phi, a = a,
