@@ -7,14 +7,14 @@
 diri.reg2 <- function(y, x, xnew = NULL) {
   ## y is the compositional data
   y <- as.matrix(y)
-  y <- y / as.vector( Rfast::rowsums(y) )
-  n <- nrow(y)  ## sample size
+  y <- y / Rfast::rowsums(y)
+  n <- dim(y)[1]  ## sample size
   mat <- model.matrix(y ~ ., as.data.frame(x) )
-  x <- as.matrix(mat[1:n, ])  ## the desing matrix is created
-  p <- ncol(x)  ## dimensionality of x
+  x <- mat[1:n, ]  ## the design matrix is created
+  p <- dim(x)[2]  ## dimensionality of x
   ## the line above makes sure y is compositional data and
   ## then the unit vector is added to the design matrix
-  d <- ncol(y) - 1
+  d <- dim(y)[2] - 1
   z <- list(y = log(y), x = x)  ## dimensionality of the simplex
 
     dirireg2 <- function(param, z = z) {
@@ -23,9 +23,9 @@ diri.reg2 <- function(y, x, xnew = NULL) {
       y <- z$y
       x <- z$x
       ## y is the compositional data and x the independent variable(s)
-      p <- ncol(x)  ## dimensionality of x
-      n <- nrow(y)  ## sample size
-      d <- ncol(y) - 1  ## dimensionality of  the simplex
+      p <- dim(x)[2]  ## dimensionality of x
+      n <- dim(y)[1]  ## sample size
+      d <- dim(y)[2] - 1  ## dimensionality of  the simplex
       phipar <- param[1:p]
       para <- param[ -c(1:p) ]
       phi <- exp( x %*% phipar )  ## phi is a function of the covariates
@@ -33,7 +33,7 @@ diri.reg2 <- function(y, x, xnew = NULL) {
       mu1 <- cbind( 1, exp(x %*% be) )
       ma <- mu1 / rowSums(mu1)  ## the fitted values
       ba <- as.vector(phi) * ma
-      l <-  -( sum( lgamma(phi) ) - sum( lgamma(ba) ) +   sum( y * (ba - 1) ) )
+      l <-  - sum( lgamma(phi) ) + sum( lgamma(ba) ) - sum( y * (ba - 1) )
       ## l is the log-likelihood
       l
     }
@@ -63,7 +63,7 @@ diri.reg2 <- function(y, x, xnew = NULL) {
   para <- qa$estimate[-c(1:p)]  ## estimated parameter values
   beta <- matrix(para, ncol = d)  ## matrix of the betas
   mu1 <- cbind( 1, exp(x %*% beta) )
-  ma <- mu1 / rowSums(mu1)  ## fitted values
+  ma <- mu1 / Rfast::rowsums(mu1)  ## fitted values
   phi <- as.numeric( exp(x %*% phipar) )  ## estimated beta parameters of phi
   s <- sqrt( diag( solve(qa$hessian) ) )  ## std of the estimated parameters
   std.phi <- s[1:p]  ## std of the estimated beta parameters of the phi
@@ -77,19 +77,19 @@ diri.reg2 <- function(y, x, xnew = NULL) {
   } else  colnames(beta) <- colnames(seb) <- paste("Y", 1:d, sep = "")
 
   if ( !is.null(xnew) ) {
-    xnew <- cbind(1, xnew)
-    xnew <- as.matrix(xnew)
+    xnew <- model.matrix(y ~ ., as.data.frame(xnew) )
+    xnew <- xnew[1:dim(xnew)[1], ]
     mu <- cbind( 1, exp(xnew %*% beta) )
-    est <- mu / as.vector( Rfast::rowsums(mu) )
+    est <- mu / Rfast::rowsums(mu) 
 
   } else {
     mu <- cbind( 1, exp(x %*% beta) )
-    est <- mu / as.vector( Rfast::rowsums(mu) ) ## fitted values
+    est <- mu / Rfast::rowsums(mu)  ## fitted values
   }
 
 
   if ( is.null(colnames(x)) ) {
-    p <- ncol(x) - 1
+    p <- dim(x)[2] - 1
     rownames(beta) <- c("constant", paste("X", 1:p, sep = "") )
     if ( !is.null(seb) )  rownames(seb) <- c("constant", paste("X", 1:p, sep = "") )
   } else {
