@@ -11,18 +11,18 @@ frechet <- function(x, a) {
   ## x contains the compositional data
   ## a is the power parameter, usually between -1 and 1
   x <- as.matrix(x)  ## makes sure x is a matrix
-  x <- x / as.vector( Rfast::rowsums(x) )  ## makes sure x is compositional data
+  x <- x / Rfast::rowsums(x)  ## makes sure x is compositional data
 
-  if (a == 0) {
+  if ( a == 0 ) {
      xa <- log(x)
-     y <- xa - as.vector( Rfast::rowmeans(xa) )
-     m1 <- exp( as.vector( Rfast::colmeans(y) ) )
+     y <- xa - Rfast::rowmeans(xa) 
+     m1 <- exp( Rfast::colmeans(y) ) 
      m <- m1 / sum( m1 )  ## closed geometric mean
 
   }  else {
      xa <- x^a
-     z <- xa / as.vector( Rfast::rowmeans(xa) )
-     m1 <- as.vector( Rfast::colmeans(z) ) ^ ( 1 / a )
+     z <- xa / Rfast::rowmeans(xa)
+     m1 <- Rfast::colmeans(z) ^ ( 1 / a )
      m <- m1 / sum(m1)  ## frechet mean in general
   }
 
