@@ -27,11 +27,11 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
 
   y1 <- as.matrix(y1)
   y2 <- as.matrix(y2)
-  p <- ncol(y1)  ## dimensionality of the data
-  n1 <- nrow(y1)  ;  n2 <- nrow(y2)  ## sample sizes
+  p <- dim(y1)[2]  ## dimensionality of the data
+  n1 <- dim(y1)[1]   ;   n2 <- dim(y2)[1]  ## sample sizes
   n <- n1 + n2  ## the total sample size
-  ybar1 <- as.vector( Rfast::colmeans(y1) ) ## sample mean vector of the first sample
-  ybar2 <- as.vector( Rfast::colmeans(y2) )  ## sample mean vector of the second sample
+  ybar1 <- Rfast::colmeans(y1)  ## sample mean vector of the first sample
+  ybar2 <- Rfast::colmeans(y2)  ## sample mean vector of the second sample
   dbar <- ybar2 - ybar1  ## difference of the two mean vectors
   mesoi <- rbind(ybar1, ybar2)
   rownames(mesoi) <- c("Sample 1", "Sample 2")
@@ -51,9 +51,9 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
 
   if (R == 1) {
     ## James test
-    A <- 1 + (1/(2 * p)) * ( trb1^2/(n1 - 1) + trb2^2/(n2 - 1) )
-    B <- ( 1/(p * (p + 2)) ) * ( sum(b1 * b1) / (n1 - 1) +
-         sum(b2 * b2)/(n2 - 1) + 0.5 * trb1 ^ 2/ (n1 - 1) + 0.5 * trb2^2/(n2 - 1) )
+    A <- 1 + ( trb1^2/(n1 - 1) + trb2^2/(n2 - 1) ) / (2 * p)
+    B <- ( sum(b1 * b1) / (n1 - 1) + sum(b2 * b2)/(n2 - 1) + 
+	     0.5 * trb1 ^ 2/ (n1 - 1) + 0.5 * trb2^2/(n2 - 1) ) / (p * (p + 2))
     x2 <- qchisq(1 - a, p)
     delta <- (A + B * x2)
     twoha <- x2 * delta  ## corrected critical value of the chi-square
@@ -65,10 +65,9 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
 
   } else if (R == 2) {
     ## MNV test
-    low <- ( sum( b1^2 ) + trb1^2 ) / n1 +
-      ( sum( b2^2 ) + trb2^2 ) / n2
+    low <- ( sum( b1^2 ) + trb1^2 ) / n1 + ( sum( b2^2 ) + trb2^2 ) / n2
     v <- (p + p^2) / low
-    test <- as.numeric( ( (v - p + 1) / (v * p) ) * test )  ## test statistic
+    test <- as.numeric( (v - p + 1) / (v * p) * test )  ## test statistic
     crit <- qf(1 - a, p, v - p + 1)  ## critical value of the F distribution
     pvalue <- pf(test, p, v - p + 1, lower.tail = FALSE)  ## p-value of the test statistic
     info <- c(test, pvalue, crit, p, v - p + 1)
@@ -79,7 +78,7 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
   } else  if (R > 2) {
     ## bootstrap calibration
     runtime <- proc.time()
-    a1inv <- chol2inv( chol(A1) )
+    a1inv <- chol2inv( chol(A1) )  
     a2inv <- chol2inv( chol(A2) )
     mc <- solve( a1inv + a2inv ) %*% ( a1inv %*% ybar1 + a2inv %*% ybar2 )
     ## mc is the combined sample mean vector
@@ -95,7 +94,7 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
       b1 <- sample(1:n1, n1, replace = TRUE)
       b2 <- sample(1:n2, n2, replace = TRUE)
       xb1 <- x1[b1, ]     ;      xb2 <- x2[b2, ]
-      db <- as.vector( Rfast::colmeans(xb1) ) - as.vector( Rfast::colmeans(xb2) )  ## difference of the two mean vectors
+      db <- Rfast::colmeans(xb1) - Rfast::colmeans(xb2)  ## difference of the two mean vectors
       Vb <- cov(xb1) / n1 + cov(xb2) / n2  ## covariance matrix of the difference
       tb[i] <- sum( db %*% solve(Vb, db ) )
     }
@@ -113,4 +112,4 @@ james <- function(y1, y2, a = 0.05, R = 999, graph = FALSE) {
   }
 
   result
-}
+}
\ No newline at end of file
