@@ -16,10 +16,10 @@ rcompnorm <- function(n, m, s, type = "alr") {
     y <- cbind( 1, exp(x) )
 
   } else {
-    D <- ncol(x)
+    D <- dim(x)[2]
     y <- x %*% helm(D + 1)
     y < exp(y)
   }
 
-  y / as.vector( Rfast::rowsums(y) )
+  y / Rfast::rowsums(y)
 }
