@@ -34,12 +34,12 @@ rmixcomp <- function(n, prob, mu, sigma, type = "alr") {
 
   if (type == "alr") {
     x1 <- cbind(1, exp(x) )
-    x <- x1 / as.vector( Rfast::rowsums(x1) )
+    x <- x1 / Rfast::rowsums(x1) 
 
   } else {
     x1 <- tcrossprod( x, helm( p + 1) )
     x2 <- exp(x1)
-    x <- x2 / as.vector( Rfast::rowsums( x2 ) )
+    x <- x2 / Rfast::rowsums( x2 ) 
   }
 
   ## x is the simulated data
