@@ -19,16 +19,17 @@ skewnorm.contour <- function(x, type = 'alr', n = 100, appear = TRUE) {
   ## If type='ilr', the isometric log-ratio is used
   ## n is the number of points of each axis used
   x <- as.matrix(x)
-  x <- x / as.vector( Rfast::rowsums(x) )
+  x <- x / Rfast::rowsums(x) 
   ha <- t( helm(3) )
 
   if (type == "alr") {
     ya <- log( x[, -3] / x[, 3] )
   } else {
     ya <- log(x)
-    ya <- ya - as.vector( Rfast::rowmeans( ya ) )
+    ya <- ya - Rfast::rowmeans( ya )
     ya <- as.matrix( ya %*% ha )
   }
+
   sqrt3 <- sqrt(3)
   mod <- sn::msn.mle(y = ya)
   param <- mod$dp
@@ -41,14 +42,14 @@ skewnorm.contour <- function(x, type = 'alr', n = 100, appear = TRUE) {
      ## This checks if the point lies inside the triangle
     if ( x2[j] < sqrt3 * x1[i] ) {
      ## The next 4 lines calculate the composition
-     w3 <- (2 * x2[j]) / sqrt3
+     w3 <- 2 * x2[j] / sqrt3
      w2 <- x1[i] - x2[j] / sqrt3
      w1 <- 1 - w2 - w3
      w <- c(w1, w2, w3)
      if (type == 'alr') {
 	   y <- log(w[-3] / w[3])  ## additive log-ratio transformation
      } else {
-       y <- log(w) - mean(log(w))
+       y <- log(w) - mean( log(w) )
        y <- as.vector( y %*% ha )
 	 }  ## isometric log-ratio transformation
      can <- sn::dmsn(y, dp = param)
@@ -57,12 +58,12 @@ skewnorm.contour <- function(x, type = 'alr', n = 100, appear = TRUE) {
    }
   }
 
-  for ( i in c(n/2+1):n ) {
+  for ( i in c(n/2 + 1):n ) {
    for ( j in  1:n )       {
    ## This checks if the point will lie inside the triangle
     if ( x2[j] < sqrt3 - sqrt3 * x1[i] ) {
      ## The next 4 lines calculate the composition
-     w3 <- (2 * x2[j]) / sqrt3
+     w3 <- 2 * x2[j] / sqrt3
      w2 <- x1[i] - x2[j] / sqrt3
      w1 <- 1 - w2 - w3
      w <- c(w1, w2, w3)
@@ -73,14 +74,14 @@ skewnorm.contour <- function(x, type = 'alr', n = 100, appear = TRUE) {
        y <- as.vector( y %*% ha )
 	 }  ## isometric log-ratio transformation
      can <- sn::dmsn(y, dp = param)
-    if ( abs(can) < Inf )  mat[i, j] <- can  else mat[i, j] <- NA
+     if ( abs(can) < Inf )  mat[i, j] <- can  else mat[i, j] <- NA
 	}
    }
   }
 
   contour(x1, x2, mat, nlevels = 7, col = 3, pty = "s", xaxt = "n",
   yaxt = "n", bty = "n")
-  b1 <- c(1/2, 0, 1, 1/2)
+  b1 <- c(0.5, 0, 1, 0.5)
   b2 <- c(sqrt3/2, 0, 0, sqrt3/2)
   b <- cbind(b1, b2)
   points(b[, 1], b[, 2], type = "l", xlab = " ", ylab = " ")
@@ -90,8 +91,7 @@ skewnorm.contour <- function(x, type = 'alr', n = 100, appear = TRUE) {
    if ( is.null(nam) )  nam <- paste("X", 1:3, sep = "")
    text(b[1, 1], b[1, 2] + 0.02, nam[3], cex = 1)
    text(b[2:3, 1], b[2:3, 2] - 0.02, nam[1:2], cex = 1)
-   proj <- matrix(c(0, 1, 1/2, 0, 0, sqrt3/2), ncol = 2)
-   x <- as.matrix(x) ; x = x/rowSums(x)
+   proj <- matrix(c(0, 1, 0.5, 0, 0, sqrt3/2), ncol = 2)
    xa <- x %*% proj
    points(xa[, 1], xa[, 2])
   }
